@@ -22,5 +22,21 @@ CREATE TABLE IF NOT EXISTS container_deployment_queue (
 
 -- Add queue_id column to sites table to track deployment status
 ALTER TABLE sites ADD COLUMN IF NOT EXISTS queue_id INT NULL;
-ALTER TABLE sites ADD CONSTRAINT IF NOT EXISTS fk_sites_queue 
-    FOREIGN KEY (queue_id) REFERENCES container_deployment_queue(id) ON DELETE SET NULL;
\ No newline at end of file
+
+-- Add foreign key constraint (with check to prevent duplicate)
+SET @constraint_exists = (
+    SELECT COUNT(*) 
+    FROM information_schema.TABLE_CONSTRAINTS 
+    WHERE CONSTRAINT_SCHEMA = 'whp' 
+    AND TABLE_NAME = 'sites' 
+    AND CONSTRAINT_NAME = 'fk_sites_queue'
+);
+
+SET @sql = IF(@constraint_exists = 0, 
+    'ALTER TABLE sites ADD CONSTRAINT fk_sites_queue FOREIGN KEY (queue_id) REFERENCES container_deployment_queue(id) ON DELETE SET NULL',
+    'SELECT "Constraint fk_sites_queue already exists"'
+);
+
+PREPARE stmt FROM @sql;
+EXECUTE stmt;
+DEALLOCATE PREPARE stmt;
\ No newline at end of file
